@@ -1,6 +1,11 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/view_jpeg_photo.php,v 1.6 2004/08/15 17:39:20 uugdave Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/view_jpeg_photo.php,v 1.8 2005/03/12 14:09:38 wurley Exp $
 
+/**
+ * @package phpLDAPadmin
+ */
+/**
+ */
 
 require './common.php';
 
@@ -9,21 +14,22 @@ $file = $_GET['file'];
 // Security check (we don't want anyone tryting to get at /etc/passwd or something)
 preg_match( "/^pla/", $file ) or 
 	pla_error( $lang['unsafe_file_name'] . htmlspecialchars( $file ) );
-
-$file = $jpeg_temp_dir . '/' . $file;
-file_exists( $file ) or
-	pla_error( $lang['no_such_file'] . htmlspecialchars( $file ) );
+// Slashes and dots are not permitted in these names:
+if( preg_match( "/[\.\/\\\\]/", $file ) )
+	pla_error( $lang['unsafe_file_name'] . htmlspecialchars( $file ) );
 
 // little security measure here (prevents users from accessing
 // files, like /etc/passwd for example)
 $file = basename( $file );
 $file = addcslashes( $file, '/\\' );
-$f = fopen( "$jpeg_temp_dir/$file", 'r' );
-$jpeg = fread( $f, filesize( "$jpeg_temp_dir/$file" ) );
+$file = $jpeg_temp_dir . '/' . $file;
+file_exists( $file ) or
+	pla_error( $lang['no_such_file'] . htmlspecialchars( $_GET['file'] ) );
+$f = fopen( $file, 'r' );
+$jpeg = fread( $f, filesize( $file ) );
 fclose( $f );
 
 Header( "Content-type: image/jpeg" );
 Header( "Content-disposition: inline; filename=jpeg_photo.jpg" );
 echo $jpeg;
-
 ?>
